You are encouraged to add information about all relevant sections, but not required to submit an issue.

#### Code Sample, a copy-pastable example if possible

A "Minimal, Complete and Verifiable Example" will make it much easier for maintainers to help you:
<http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports>

```python
# Your code here
```

#### Problem description

This should explain **why** the current behaviour is a problem and why the expected output is a better solution.

#### Expected Output

#### Output of `climpred.show_versions()`

<details>
# Paste the output here climpred.show_versions() here

</details>
